@@ -16,7 +16,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  *
- * $Id: checkin.cc 1.22.1.2.1.9.1.23.1.1.1.6.1.15.1.2.1.33 Wed, 14 Jan 1998 23:22:44 -0800 jmacd $
+ * $Id: checkin.cc 1.22.1.2.1.9.1.23.1.1.1.6.1.15.1.2.1.39 Wed, 14 Oct 1998 20:50:34 -0700 jmacd $
  */
 
 #include "prcs.h"
@@ -56,7 +56,7 @@ PrPrcsExitStatusError checkin_command()
     Return_if_fail(project << read_project_file(cmd_root_project_full_name,
 						cmd_root_project_file_path,
 						true,
-						(ProjectReadData)(KeepMergeParents | KeepKeywords)));
+						(ProjectReadData)(KeepMergeParents)));
 
     install_cleanup_handler(checkin_cleanup_handler, project);
 
@@ -311,7 +311,7 @@ PrVoidError check_project(ProjectDescriptor *project)
 	     * files for empty descriptors, complain. */
 
 	    If_fail (fe->stat()) {
-		throw prcserror << "The file " << squote(name)
+		pthrow prcserror << "The file " << squote(name)
 				<< " has an empty descriptor and does not exist.  You may not "
 		    "do a partial checkin excluding files with empty descriptors" << dotendl;
 	    } else {
@@ -339,7 +339,7 @@ PrVoidError check_project(ProjectDescriptor *project)
 	    If_fail(data << project->repository_entry()->
 		    lookup_rcs_file_data(fe->descriptor_name(),
 					 fe->descriptor_version_number()))
-		throw prcserror << "The missing file may have been in a project version "
+		pthrow prcserror << "The missing file may have been in a project version "
 		           "which was deleted" << dotendl;
 
 	}
@@ -410,8 +410,7 @@ static PrVoidError checkin_each_file(ProjectDescriptor *project)
 				  fe->full_descriptor_name(),
 				  NULL,
 				  fe,
-				  checkin_hook,
-				  false));
+				  checkin_hook));
     }
 
     Dstring rlog;
@@ -420,7 +419,7 @@ static PrVoidError checkin_each_file(ProjectDescriptor *project)
 		  prcs_version_number[1],
 		  prcs_version_number[2]);
 
-    Return_if_fail(VC_checkin(NULL, NULL, NULL, rlog, NULL, checkin_hook, false));
+    Return_if_fail(VC_checkin(NULL, NULL, NULL, rlog, NULL, checkin_hook));
 
     /* This is a hack to fix a problem with RCS 5.7.  It does not
      * respect the mode of a file created by rcs -i at the initial
@@ -450,7 +449,8 @@ static PrVoidError checkin_each_file(ProjectDescriptor *project)
 void eliminate_unnamed_files(ProjectDescriptor* project)
 {
     if(cmd_filenames_count < 1) {
-        cmd_prj_given_as_file = true;
+        if (! option_exclude_project_file)
+	    cmd_prj_given_as_file = true;
         return;
     }
 
@@ -523,7 +523,7 @@ PrVoidError warn_unused_files(bool prompt_abort)
     }
 
     if(!any)
-	throw prcserror << "No files on command line match working files" << dotendl;
+	pthrow prcserror << "No files on command line match working files" << dotendl;
 
     if(need_prompt) {
 	prcsquery << "Files on the command line did not match files in the project.  "
@@ -580,7 +580,7 @@ static PrVoidError maybe_query_user(ProjectDescriptor* P)
 
     while(true) {
 	If_fail(c << Err_fgetc(stdin))
-	    throw prcserror << "Read failure on stdin" << perror;
+	    pthrow prcserror << "Read failure on stdin" << perror;
 
 	if (c == EOF) {
 	    fprintf (stdout, "\n");
@@ -606,7 +606,7 @@ static PrVoidError maybe_query_user(ProjectDescriptor* P)
     /* I don't think its possible that PRCS will ever need to query the
      * user after this, but I might as well reopen it. */
     if(freopen(ctermid(NULL), "r", stdin) == NULL)
-	throw prcserror << "Couldn't reopen the standard input" << perror;
+	pthrow prcserror << "Couldn't reopen the standard input" << perror;
 
     return NoError;
 }
@@ -632,7 +632,7 @@ ProjectDescriptor::resolve_checkin_version(const char          *maj,
 	first_parent_project_data = repository_entry()->lookup_version(this);
 
 	if(!first_parent_project_data)
-	    throw prcserror << "Illegal version, " << full_version()
+	    pthrow prcserror << "Illegal version, " << full_version()
 			    << ", in project file, it may have been deleted" << dotendl;
 
 	cur_project_data->new_parent(first_parent_project_data->version_index());
@@ -656,7 +656,7 @@ ProjectDescriptor::resolve_checkin_version(const char          *maj,
 	/* We assume that the first parent is a the Parent-Version field, so we can't
 	 * add Merge-Parents if we didn't add a Parent-Version. */
 	if (_merge_parents->length() > 0)
-	    throw prcserror << "Kind of strange to have merge parents when you're an empty "
+	    pthrow prcserror << "Kind of strange to have merge parents when you're an empty "
 		"version, isn't it?" << prcsendl;
     }
 
@@ -667,14 +667,14 @@ ProjectDescriptor::resolve_checkin_version(const char          *maj,
 	int highest_major;
 
 	if(repository_entry()->version_count() == 0)
-	    throw prcserror << "No versions in the repository, can't resolve major version '@'" << dotendl;
+	    pthrow prcserror << "No versions in the repository, can't resolve major version '@'" << dotendl;
 
 	highest_major = repository_entry()->highest_major_version();
 
 	if(highest_major >= 0) {
 	    new_major->assign_int(highest_major);
 	} else
-	    throw prcserror << "No numeric major versions in the repository, "
+	    pthrow prcserror << "No numeric major versions in the repository, "
 		"can't resolve major version '@'" << dotendl;
     } else {
 	new_major->assign(maj);
@@ -757,11 +757,11 @@ ProjectDescriptor::resolve_checkin_version(const char          *maj,
 	}
 
 	if (!ancestor_unique || ancestor_diff) {
-	    prcsquery << report ("Continue")
-		      << force ("Continuing")
-		      << optfail ('n')
-		      << defopt ('y', "Continue this checkin")
-		      << query ("Continue");
+	    prcsquery << report ("Query Abort/Force Continue")
+		      << force ("Continuing", 'n')
+		      << option ('n', "Continue, ignoring warning")
+		      << deffail ('y')
+		      << query ("Abort");
 
 	    Return_if_fail (prcsquery.result());
 	}
@@ -789,7 +789,7 @@ PrVoidError ProjectDescriptor::checkin_project_file(ProjectVersionData *new_proj
         (*fe_ptr)->update_repository(repository_entry());
 
     If_fail(Err_stat(project_file_path(), &buf))
-	throw prcserror << "Stat failed on newly written project file " << project_file_path() << perror;
+	pthrow prcserror << "Stat failed on newly written project file " << project_file_path() << perror;
 
     new_project_data->date(get_utc_time_t());
     new_project_data->author(get_login());
@@ -797,25 +797,42 @@ PrVoidError ProjectDescriptor::checkin_project_file(ProjectVersionData *new_proj
 
     format_version_log(new_project_data, version_log);
 
-    If_fail(VC_checkin(project_file_path(),
+    Dstring tmp_name (repository_entry()->Rep_name_of_version_file());
+    const char* abs_path;
+
+    Return_if_fail (abs_path << absolute_path (project_file_path()));
+
+    tmp_name.truncate (tmp_name.length() - 2);
+
+    unlink (tmp_name);
+
+    If_fail (Err_symlink (abs_path, tmp_name))
+      pthrow prcserror << "Error creating symbolic link "
+		      << squote(tmp_name) << perror;
+
+    If_fail(VC_checkin(tmp_name,
 		       "",
 		       repository_entry()->Rep_name_of_version_file(),
 		       NULL,
 		       &new_rcs_version,
-		       checkin_prj_hook,
-		       true))
-	throw prcserror << "Failure checking in project file" << dotendl;
+		       checkin_prj_hook))
+	pthrow prcserror << "Failure checking in project file" << dotendl;
 
-    If_fail(VC_checkin(NULL, NULL, NULL, version_log, NULL, checkin_prj_hook, true))
-	throw prcserror << "Failure checking in project file" << dotendl;
+    If_fail(VC_checkin(NULL, NULL, NULL, version_log, NULL, checkin_prj_hook))
+	pthrow prcserror << "Failure checking in project file" << dotendl;
+
+    unlink (tmp_name);
 
     /* RCS restores the RCS mode to this file, since it wasn't temp. */
-    If_fail(Err_chmod (project_file_path(), buf.st_mode & 0777))
-	throw prcserror << "Chmod failed on " << squote (project_file_path()) << perror;
+    /*If_fail(Err_chmod (project_file_path(), buf.st_mode & 0777))
+	pthrow prcserror << "Chmod failed on " << squote (project_file_path()) << perror;*/
 
-    /* Hack to get around RCS bug */
+    /* ->  964   X 970419 Paul Eggert       ( 30) Re: RCS file permissions */
+
+    /* Hack to get around RCS init bug.  It throws away the rcs -i
+     * mode, user, etc. at first checkin. */
     if (strcmp (new_rcs_version, "1.1") == 0) {
-	Dstring desc_name (project_name());
+        Dstring desc_name (project_name());
 	desc_name.append (".prj");
 
 	Return_if_fail(repository_entry()->Rep_chown_file(desc_name));
@@ -889,7 +906,7 @@ static PrVoidError slow_eliminate_prepare(ProjectDescriptor *project)
 	    continue;
 
 	If_fail(file_buffer.map_file(fe->working_path()))
-	    throw prcserror << "Error reading file " << squote(fe->working_path())
+	    pthrow prcserror << "Error reading file " << squote(fe->working_path())
 			    << perror;
 
 	if(fe->keyword_sub()) {
@@ -898,7 +915,7 @@ static PrVoidError slow_eliminate_prepare(ProjectDescriptor *project)
 						 &setkey_buffer,
 						 fe,
 						 Unsetkeys))
-		throw prcserror << "Keyword replacement failed on file "
+		pthrow prcserror << "Keyword replacement failed on file "
 			        << squote(fe->working_path()) << perror;
 
 	    output_buffer = setkey_buffer.segment();
@@ -950,22 +967,22 @@ static PrVoidError slow_eliminate_prepare(ProjectDescriptor *project)
 		fullpath = make_temp_file("");
 
 		If_fail(temp_out << Err_fopen(fullpath, "w"))
-		    throw prcserror << "Failed opening temp file for writing "
+		    pthrow prcserror << "Failed opening temp file for writing "
 				    << squote(fullpath) << perror;
 
-		if(fwrite(output_buffer, output_len, 1, temp_out) != 1)
-		    throw prcserror << "Failed writing temp file "
+		If_fail (Err_fwrite(output_buffer, output_len, temp_out))
+		    pthrow prcserror << "Failed writing temp file "
 				    << squote(fullpath) << perror;
 
-		If_fail(Err_fclose(temp_out))
-		    throw prcserror << "Failed writing temp file "
+		If_fail (Err_fclose(temp_out))
+		    pthrow prcserror << "Failed writing temp file "
 				    << squote(fullpath) << perror;
 	    } else {
 		Return_if_fail(fullpath << name_in_cwd(fe->working_path()));
 	    }
 
 	    If_fail (Err_symlink(fullpath, fe->temp_file_path())) {
-		throw prcserror << "Error creating symbolic link "
+		pthrow prcserror << "Error creating symbolic link "
 				<< squote(fe->temp_file_path()) << perror;
 	    }
 
