@@ -16,7 +16,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  *
- * $Id: checkout.cc 1.16.1.24.1.3.1.8.1.1.1.19 Sun, 06 Jul 1997 01:37:54 -0700 jmacd $
+ * $Id: checkout.cc 1.16.1.24.1.3.1.8.1.1.1.25 Tue, 06 Oct 1998 13:31:13 -0700 jmacd $
  */
 
 #include "prcs.h"
@@ -43,7 +43,7 @@ static PrVoidError checkout_nokeywords(FileEntry*);
 static PrOverwriteStatusError check_overwrite_different_file_type(FileEntry*);
 
 static const char new_project_format[] =
-";; -*- Lisp -*-\n"
+";; -*- Prcs -*-\n"
 "(Created-By-Prcs-Version %d %d %d)\n"
 "(Project-Description \"\")\n"
 "(Project-Version %s %s 0)\n"
@@ -111,7 +111,7 @@ PrPrcsExitStatusError checkout_command()
 
     Return_if_fail(project << rep_entry->checkout_prj_file(cmd_root_project_full_name,
 							   project_data->rcs_version(),
-							   KeepKeywords));
+							   KeepNothing));
 
     project->read_quick_elim();
 
@@ -138,7 +138,7 @@ static PrPrcsExitStatusError create_empty_project()
 
     /* sortof a kludge, so that write_new_prj_file thinkgs it needs
      * to write the project file. */
-    cmd_prj_given_as_file = 1;
+    cmd_prj_given_as_file = true;
 
     Return_if_fail(new_project << checkout_empty_prj_file(cmd_root_project_full_name,
 							  cmd_version_specifier_major,
@@ -157,13 +157,27 @@ PrVoidError check_create_subdir(const char* dir)
 
     if(stat(dir, &buf) >= 0) {
 
-	if (!S_ISDIR(buf.st_mode))
-            throw prcserror << "Required subdirectory "
-			    << squote(dir) << " exists and is not an executable directory" << dotendl;
+        if (!S_ISDIR(buf.st_mode)) {
+	    prcsquery << "Required subdirectory "
+		      << squote(dir)
+		      << " exists and is not a directory.  "
+		      << force ("Deleting")
+		      << report ("Delete")
+		      << optfail ('n')
+		      << defopt ('y', "Delete the file, replacing it with the required directory")
+		      << query ("Delete");
 
-    } else {
-	If_fail(Err_mkdir(dir, (mode_t)0777))
-	    throw prcserror << "Couldn't create required subdirectory " << squote(dir) << perror;
+	    Return_if_fail (prcsquery.result ());
+
+	    If_fail (fs_nuke_file (dir))
+	        pthrow prcserror << "Couldn't remove file " << squote (dir) << perror;
+	} else {
+	  return NoError;
+	}
+    }
+
+    If_fail(Err_mkdir(dir, (mode_t)0777)) {
+        pthrow prcserror << "Couldn't create required subdirectory " << squote(dir) << perror;
     }
 
     return NoError;
@@ -287,7 +301,7 @@ static PrVoidError checkout_symlink(FileEntry* fe)
 	    return NoError;
 
 	If_fail(Err_unlink(filename)) {
-            throw prcserror << "Can't unlink old symlink "
+            pthrow prcserror << "Can't unlink old symlink "
 			     << squote(filename) << perror;
         }
     }
@@ -296,7 +310,7 @@ static PrVoidError checkout_symlink(FileEntry* fe)
 
     if(!option_report_actions) {
 	If_fail(Err_symlink(fe->link_name(), filename)) {
-	    throw prcserror << "Failed creating symlink " << squote(filename)
+	    pthrow prcserror << "Failed creating symlink " << squote(filename)
 			     << perror;
 	}
     }
@@ -420,7 +434,7 @@ static PrVoidError checkout_keywords(FileEntry* fe)
 	/* version_data->length() is an optimization to avoid resizing the
 	 * buffer each time the pipe data doubles in size */
 	If_fail(unsetkey_buffer.map_file(fileno(cofile), version_data->length()))
-	    throw prcserror << "Read failed from RCS co pipe" << perror;
+	    pthrow prcserror << "Read failed from RCS co pipe" << perror;
 
 	Return_if_fail(VC_close_checkout_stream(cofile,
 						fe->descriptor_version_number(),
@@ -452,7 +466,7 @@ static PrVoidError checkout_keywords(FileEntry* fe)
 	    /* Length is the same, now try memcmp */
 
 	    If_fail(file_buffer.map_file(filename))
-		throw prcserror << "Read error on " << squote(filename) << perror;
+		pthrow prcserror << "Read error on " << squote(filename) << perror;
 
 	    if(memcmp(new_setkey_buf, file_buffer.segment(), new_unsetkey_len) == 0) {
 		/* No differences. */
@@ -543,7 +557,7 @@ static PrVoidError checkout_keywords(FileEntry* fe)
 	Return_if_fail(fe->utime(version_data->date()));
 
 	If_fail(fe->stat())
-	    throw prcserror << "Stat failed on file " << squote(filename) << perror;
+	    pthrow prcserror << "Stat failed on file " << squote(filename) << perror;
 
 	fe->project()->quick_elim_update_fe(fe);
     }
@@ -575,7 +589,7 @@ static PrVoidError checkout_nokeywords(FileEntry* fe)
 	if(version_data->length() == fe->stat_length()) {
 
 	    If_fail(file_buffer.map_file(filename))
-		throw prcserror << "Read error on " << squote(filename) << perror;
+		pthrow prcserror << "Read error on " << squote(filename) << perror;
 
 	    char* checksum = md5_buffer(file_buffer.segment(), file_buffer.length());
 
@@ -626,7 +640,7 @@ static PrVoidError checkout_nokeywords(FileEntry* fe)
 	Return_if_fail(fe->utime(version_data->date()));
 
 	If_fail(fe->stat())
-	    throw prcserror << "Stat failed on file " << squote(filename) << perror;
+	    pthrow prcserror << "Stat failed on file " << squote(filename) << perror;
 
 	fe->project()->quick_elim_update_fe(fe);
     }
@@ -685,7 +699,7 @@ static PrOverwriteStatusError check_overwrite_different_file_type(FileEntry* fe)
 
     if(!option_report_actions) {
 	If_fail(fs_nuke_file(fe->working_path()))
-	    throw prcserror << "Couldn't remove file " << squote(fe->working_path())
+	    pthrow prcserror << "Couldn't remove file " << squote(fe->working_path())
 			     << perror;
     }
 
@@ -694,11 +708,11 @@ static PrOverwriteStatusError check_overwrite_different_file_type(FileEntry* fe)
 
 static PrVoidError write_new_prj_file(ProjectDescriptor* project)
 {
-    if(option_report_actions)
+    if(option_report_actions || option_exclude_project_file)
         return NoError;
 
     if(fs_file_exists(cmd_root_project_file_path)) {
-        if(!cmd_prj_given_as_file) {
+        if (!cmd_prj_given_as_file) {
             return NoError;
         }
 
@@ -737,7 +751,7 @@ PrProjectDescriptorPtrError checkout_create_empty_prj_file(const char* fullname,
     FILE* prj;
 
     If_fail ( prj << Err_fopen(name, "w") )
-        throw prcserror << "Cannot create temp file " << squote(name) << perror;
+        pthrow prcserror << "Cannot create temp file " << squote(name) << perror;
 
     fprintf (prj, new_project_format,
 	     prcs_version_number[0],
@@ -749,7 +763,7 @@ PrProjectDescriptorPtrError checkout_create_empty_prj_file(const char* fullname,
 	     get_login());
 
     If_fail( Err_fclose(prj) )
-        throw prcserror << "Error writing temp file " << squote(name) << perror;
+        pthrow prcserror << "Error writing temp file " << squote(name) << perror;
 
     return read_project_file(fullname, name, false, flags);
 }
@@ -770,7 +784,7 @@ PrVoidError WriteableFile::open(const char* filename)
 	    Return_if_fail(real_name << find_real_filename(filename));
 
 		If_fail(Err_stat(real_name, &sbuf))
-		throw prcserror << "Stat failed on " << squote(real_name)
+		pthrow prcserror << "Stat failed on " << squote(real_name)
 				<< perror;
 	    }
 	} else {
@@ -792,7 +806,7 @@ PrVoidError WriteableFile::open(const char* filename)
     os.open(temp_name);
 
     if (os.bad())
-	throw prcserror << "Open failed on " << squote(temp_name) << perror;
+	pthrow prcserror << "Open failed on " << squote(temp_name) << perror;
 
     return NoError;
 }
@@ -802,7 +816,7 @@ PrVoidError WriteableFile::write(const char* seg, int len)
     os.write(seg, len);
 
     if (os.bad())
-	throw prcserror << "Write failed on " << squote(temp_name)
+	pthrow prcserror << "Write failed on " << squote(temp_name)
 			<< perror;
 
     return NoError;
@@ -813,13 +827,13 @@ PrVoidError WriteableFile::close()
     os.close();
 
     if (os.bad())
-	throw prcserror << "Write failed on " << squote(temp_name)
+	pthrow prcserror << "Write failed on " << squote(temp_name)
 			<< perror;
 
     if (real_name) {
 
 	If_fail(Err_rename(temp_name, real_name))
-	    throw prcserror << "Rename failed on " << squote(real_name)
+	    pthrow prcserror << "Rename failed on " << squote(real_name)
 			    << " to " << squote(temp_name)
 			    << perror;
 
