@@ -16,7 +16,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  *
- * $Id: diff.cc 1.20.1.19.1.3.1.6.1.19 Wed, 14 Oct 1998 20:50:34 -0700 jmacd $
+ * $Id: diff.cc 1.20.1.19.1.3.1.6.1.21 Sun, 31 Oct 1999 16:52:32 -0800 jmacd $
  */
 
 #include "prcs.h"
@@ -41,7 +41,7 @@ static PrPrcsExitStatusError diff_named_versions();
 static PrBoolError diff_similar_files(ProjectDescriptor* toP, ProjectDescriptor* fromP);
 static PrBoolError diff_missing_files(ProjectDescriptor* toP, ProjectDescriptor* fromP);
 static PrBoolError diff_symlink_pair(FileEntry*, FileEntry*);
-static PrBoolError diff_new_file(FileEntry*, ProjectDescriptor* fromP);
+static PrBoolError diff_old_new_file(FileEntry*, ProjectDescriptor* fromP, bool new_file);
 static PrVoidError prepare_diff_workingfile(FileEntry *fe);
 static PrIntError try_optimizations(FileEntry *tofe, FileEntry *fromfe);
 static PrVoidError prepare_diff_versionfile(FileEntry *fe, bool use_working);
@@ -518,7 +518,7 @@ static PrBoolError diff_missing_files(ProjectDescriptor* toP,
 		else
 		    Return_if_fail(prepare_diff_versionfile(fe, false));
 
-		diff_new_file (fe, fromP);
+		diff_old_new_file (fe, fromP, true);
 	    } else {
 		prcsoutput << "Only in " << toP->full_version() << ": " << fe->working_path() << prcsendl;
 	    }
@@ -537,7 +537,12 @@ static PrBoolError diff_missing_files(ProjectDescriptor* toP,
 	Return_if_fail (bogus << toP->match_fileent(fe));
 
 	if(!bogus) {
-	    prcsoutput << "Only in " << fromP->full_version() << ": " << fe->working_path() << prcsendl;
+	    if(option_diff_new_file && fe->file_type() == RealFile && !diff_option_brief) {
+		Return_if_fail(prepare_diff_versionfile(fe, false));
+		diff_old_new_file (fe, toP, false);
+	    } else {
+		prcsoutput << "Only in " << fromP->full_version() << ": " << fe->working_path() << prcsendl;
+	    }
 	    alldiffs = true;
 	}
     }
@@ -567,7 +572,7 @@ static PrBoolError diff_symlink_pair(FileEntry* to, FileEntry* from)
     }
 }
 
-static PrBoolError diff_new_file(FileEntry *to, ProjectDescriptor* fromP)
+static PrBoolError diff_old_new_file(FileEntry *to, ProjectDescriptor* fromP, bool new_file)
 {
     Dstring label1, label2;
     Dstring filedes;
@@ -600,7 +605,10 @@ static PrBoolError diff_new_file(FileEntry *to, ProjectDescriptor* fromP)
     if (to->file_attrs()->diff_tool())
 	cmd = sys_cmd_by_name (to->file_attrs()->diff_tool());
 
-    return diff_two_files(label1, label2, "/dev/null", temp_file_to, to->working_path(), fromP->full_version(), cmd);
+    if (new_file)
+	return diff_two_files(label1, label2, "/dev/null", temp_file_to, to->working_path(), fromP->full_version(), cmd);
+    else
+	return diff_two_files(label2, label1, temp_file_to, "/dev/null", to->working_path(), fromP->full_version(), cmd);
 }
 
 void format_diff_label(FileEntry* fe, const char* name, Dstring* ds)
