@@ -16,7 +16,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  *
- * $Id: execute.cc 1.10.1.24 Tue, 06 Oct 1998 13:31:13 -0700 jmacd $
+ * $Id: execute.cc 1.10.1.26 Sat, 30 Oct 1999 18:47:14 -0700 jmacd $
  */
 
 extern "C" {
@@ -203,11 +203,12 @@ static FileEntryPtrArray* eliminate_unmatched_files(ProjectDescriptor* project)
     FileTable table(pathname_hash, pathname_equal);
     FileEntryPtrArray* all_files = new FileEntryPtrArray;
 
-    add_fake (project,
-	      project->project_file_path(),
-	      ":project-file",
-	      &table,
-	      all_files);
+    if (cmd_prj_given_as_file)
+      add_fake (project,
+		project->project_file_path(),
+		":project-file",
+		&table,
+		all_files);
 
     foreach_fileent(fe_ptr, project) {
 	FileEntry* fe = *fe_ptr;
@@ -222,10 +223,9 @@ static FileEntryPtrArray* eliminate_unmatched_files(ProjectDescriptor* project)
 	    continue;
 
 	all_files->append (fe);
-    }
 
-    foreach_fileent(fe_ptr, project)
 	maybe_add_subdirs_file(*fe_ptr, &table, all_files);
+    }
 
     all_files->sort(compare_fileent);
 
@@ -447,86 +447,126 @@ outahere:
     return NoError;
 }
 
-static PrBoolError prepare_arg(FileEntryPtrArray* fe_ptrs,
-			       const char* arg,
-			       ProjectDescriptor* project,
-			       ArgList* args)
+static void
+append_name (Dstring* n, FileEntry* fe, const char* arg)
 {
-    char c;
+  const char* path = fe->working_path();
 
-    Dstring this_arg;
+  if (strncmp(arg, "}", 1) == 0)
+    n->append (path);
+  else if (strncmp(arg, "base}", 5) == 0)
+    n->append (strip_leading_path (path));
+  else if (strncmp(arg, "dir}", 4) == 0)
+    {
+      const char* last_slash = strrchr (path, '/');
 
-    while ((c = *arg++) != 0) {
-	if (c == '{') {
-	    if (strncmp(arg, "}", 1) == 0) {
-		arg += 1;
+      if (last_slash)
+	n->append (path, last_slash - path);
+      else
+	n->append (".");
+    }
+  else
+    abort ();
+}
 
-		if (fe_ptrs->length() == 0)
-		  return true;
+static PrBoolError
+prepare_arg(FileEntryPtrArray* fe_ptrs,
+	    const char* arg,
+	    ProjectDescriptor* project,
+	    ArgList* args)
+{
+  char c;
 
-		this_arg.append(fe_ptrs->index(0)->working_path());
+  Dstring this_arg;
 
-		for(int i = 1; i < fe_ptrs->length(); i += 1) {
+  while ((c = *arg++) != 0)
+    {
+      if (c == '{')
+	{
+	  if (strncmp(arg, "}", 1) == 0 ||
+	      strncmp(arg, "base}", 5) == 0 ||
+	      strncmp(arg, "dir}", 4) == 0)
+	    {
+	      if (fe_ptrs->length() == 0)
+		return true;
+
+	      append_name (& this_arg, fe_ptrs->index (0), arg);
+
+	      for (int i = 1; i < fe_ptrs->length(); i += 1)
+		{
 		  args->append(p_strdup(this_arg));
 		  this_arg.truncate(0);
-		  this_arg.append(fe_ptrs->index(i)->working_path());
+		  append_name (& this_arg, fe_ptrs->index (i), arg);
 		}
-	    } else if (strncmp(arg, "file}", 5) == 0) {
-		const char* name;
-		bool breakit = false;
-		bool any = false;
-		arg += 5;
 
-		if (fe_ptrs->length() == 0)
-		  return true;
+	      arg += strchr (arg, '}') - arg + 1;
+	    }
+	  else if (strncmp(arg, "file}", 5) == 0)
+	    {
+	      const char* name;
+	      bool breakit = false;
+	      bool any = false;
+	      arg += 5;
 
-		for(int i = 0; i < fe_ptrs->length(); i += 1) {
+	      if (fe_ptrs->length() == 0)
+		return true;
 
-		    if (fe_ptrs->index(i)->file_type() != RealFile)
-			continue;
+	      for(int i = 0; i < fe_ptrs->length(); i += 1)
+		{
 
-		    any = true;
+		  if (fe_ptrs->index(i)->file_type() != RealFile)
+		    continue;
 
-		    Return_if_fail(name << make_execute_temp_file(fe_ptrs->index(i), project));
+		  any = true;
 
-		    if (breakit) {
-			args->append(p_strdup(this_arg));
-			this_arg.truncate(0);
+		  Return_if_fail(name << make_execute_temp_file(fe_ptrs->index(i), project));
+
+		  if (breakit)
+		    {
+		      args->append(p_strdup(this_arg));
+		      this_arg.truncate(0);
 		    }
 
-		    this_arg.append(name);
+		  this_arg.append(name);
 
-		    breakit = true;
+		  breakit = true;
 		}
 
-		if (!any) /* skip it */
-		    return true;
+	      if (!any) /* skip it */
+		return true;
 
-	    } else if (strncmp(arg, "options}", 8) == 0) {
-		arg += 8;
+	    }
+	  else if (strncmp(arg, "options}", 8) == 0)
+	    {
+	      arg += 8;
 
-		if (fe_ptrs->length() == 0)
-		  return true;
+	      if (fe_ptrs->length() == 0)
+		return true;
 
-		fe_ptrs->index(0)->file_attrs()->print_to_string(&this_arg, false);
+	      fe_ptrs->index(0)->file_attrs()->print_to_string(&this_arg, false);
 
-		for(int i = 1; i < fe_ptrs->length(); i += 1) {
-		    args->append(p_strdup(this_arg));
-		    this_arg.truncate(0);
-		    fe_ptrs->index(i)->file_attrs()->print_to_string(&this_arg, false);
+	      for(int i = 1; i < fe_ptrs->length(); i += 1)
+		{
+		  args->append(p_strdup(this_arg));
+		  this_arg.truncate(0);
+		  fe_ptrs->index(i)->file_attrs()->print_to_string(&this_arg, false);
 		}
 
-	    } else {
+	    }
+	  else
+	    {
 	      this_arg.append (c);
 	    }
-	} else {
-	    this_arg.append(c);
+	}
+      else
+	{
+	  this_arg.append(c);
 	}
     }
 
-    args->append(p_strdup(this_arg));
+  args->append(p_strdup(this_arg));
 
-    return false;
+  return false;
 }
 
 static PrIntError exec_command(ArgList* args)
