@@ -16,7 +16,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  *
- * $Id: prcserror.h 1.14.1.5.1.10 Tue, 06 Oct 1998 13:31:13 -0700 jmacd $
+ * $Id: prcserror.h 1.14.1.5.1.11 Sat, 30 Oct 1999 21:26:02 -0700 jmacd $
  */
 
 
@@ -120,7 +120,7 @@ public:
 #endif
 	return _error; }
     ErrorToken error_val() const { return _tok; }
-    PrVoidError void_error() const { return *this; }
+    PrVoidError void_error() const { return PrVoidError(error_val()); }
 
 protected:
     ErrorToken _tok;
@@ -139,7 +139,7 @@ public:
 
     bool error() const { return _error; }
     ErrorToken error_val() const { return _tok; }
-    NprVoidError void_error() const { return *this; }
+    NprVoidError void_error() const { return NprVoidError(error_val()); }
 
 protected:
 
@@ -185,7 +185,7 @@ public:
 #endif
     PrError(ErrorToken tok) :PrVoidError(tok) { }
 
-    PrVoidError void_error() { return PrVoidError(error_val()); }
+    PrVoidError void_error() const { return PrVoidError(error_val()); }
     Type non_error_val() const { return _val; };
 
 private:
@@ -201,7 +201,7 @@ public:
     NprError(ErrorToken tok) :NprVoidError(tok) { }
     NprError(NprVoidError err) :NprVoidError(err) { }
 
-    NprVoidError void_error() { return NprVoidError(error_val()); }
+    NprVoidError void_error() const { return NprVoidError(error_val()); }
     Type non_error_val() const { return _val; };
 
 private:
