@@ -16,7 +16,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  *
- * $Id: merge.cc 1.18.1.1.1.26.1.1.1.4.1.9.1.37 Tue, 06 Oct 1998 13:31:13 -0700 jmacd $
+ * $Id: merge.cc 1.18.1.1.1.26.1.1.1.4.1.9.1.38 Sun, 31 Oct 1999 16:52:32 -0800 jmacd $
  */
 
 extern "C" {
@@ -1721,7 +1721,7 @@ static PrVoidError maybe_rename (FileEntry* selected,
 
 	Return_if_fail (c << prcsquery.result());
 
-	if (c == 'y') {
+	if (c == 'y' && ! option_report_actions) {
 	    working->project()->merge_log() << "The file " << squote (working->working_path())
 					    << " was renamed to "
 					    << squote (selected->working_path()) << prcsendl;
@@ -1801,7 +1801,7 @@ void MergeControl::merge_announce_os (Mergeable* selected,
 				      Mergeable* working,
 				      ostream &os)
 {
-    os << "*** Action on " << type() << " " << print3 (working, common, selected) << prcsendl;
+    os << "*** Action on " << type() << " " << print3 (selected, common, working) << prcsendl;
 }
 
 void MergeControl::merge_announce (Mergeable* selected,
@@ -1849,7 +1849,7 @@ void MergeControl::merge_action_os (Mergeable* selected,
 	break;
     }
 
-    os << desc << " " << type() << " " << print3 (working, common, selected);
+    os << desc << " " << type() << " " << print3 (selected, common, working);
 
     if (ruleno)
 	os << " by rule " << ruleno;
@@ -1935,7 +1935,7 @@ PrVoidError MergeControl::finish_merge (Mergeable* selected,
 	/* This doesn't happen for KeyPop */
 
 	prcsquery << "Normally, you would be prompted to add the " << type() << " "
-		  << print3 (working, common, selected)
+		  << print3 (selected, common, working)
 		  << ", but it already exists in the working project "
 	    "either by file name or descriptor and therefore cannot be "
 	    "added.  "
@@ -1966,7 +1966,7 @@ PrVoidError MergeControl::finish_merge (Mergeable* selected,
 
 	    project->merge_log () << "Cannot merge this " << type() << ", as it is not a regular file" << prcsendl;
 	    prcsinfo << "Cannot merge non-regular file "
-		     << print3 (working, common, selected)
+		     << print3 (selected, common, working)
 		     << ", setting default action to nothing" << dotendl;
 	}
 
@@ -1979,7 +1979,7 @@ PrVoidError MergeControl::finish_merge (Mergeable* selected,
 	Dstring valid;
 	Dstring query;
 
-	prcsoutput << "Choose an action on " << type() << " " << print3 (working, common, selected)
+	prcsoutput << "Choose an action on " << type() << " " << print3 (selected, common, working)
 		   << " for rule " << mergedef->rule_no << ": " << mergedef->help_string << dotendl;
 
 	if (may_add)
@@ -2221,8 +2221,8 @@ PrVoidError MergeControl::run_merge (Mergeable* selected,
 
     if (found == 0 ||
 	file_merge_action (selected, common, working, found_defs[0]->rule_no) == (MergeAction)0) {
-	merge_announce (working, common, selected, (MergeAction)0);
-	merge_action   (working, common, selected, (MergeAction)0, 0, false);
+	merge_announce (selected, common, working, (MergeAction)0);
+	merge_action   (selected, common, working, (MergeAction)0, 0, false);
 
 	return NoError;
     }
