@@ -16,7 +16,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  *
- * $Id: misc.cc 1.30.1.3.1.17.1.11.1.7.1.18.1.31 Wed, 14 Oct 1998 20:50:34 -0700 jmacd $
+ * $Id: misc.cc 1.30.1.3.1.17.1.11.1.7.1.18.1.33 Sun, 31 Oct 1999 16:52:32 -0800 jmacd $
  */
 
 extern "C" {
@@ -1044,10 +1044,19 @@ NprIntError Err_fread(void* buf, size_t nbytes, FILE* f)
 {
   int c;
 
+  DEBUG ("Err_fread (" << nbytes << ")");
+
   do {
     errno = 0;
     clearerr(f);
     c = fread (buf, 1, nbytes, f);
+
+    DEBUG (c << " = fread (" << nbytes << ")");
+    if (errno)
+      DEBUG ("errno = " << errno);
+    if (ferror(f))
+      DEBUG ("ferror(f) = " << ferror (f));
+
   } while (c <= 0 && ferror(f) && errno == EINTR);
 
   if (c <= 0 && ferror (f))
@@ -1060,11 +1069,20 @@ NprVoidError Err_fwrite(const void* buf, size_t nbytes, FILE* out)
 {
   int c;
 
+  DEBUG ("Err_fwrite (" << nbytes << ")");
+
   while (nbytes > 0) {
     do {
       errno = 0;
       clearerr(out);
       c = fwrite (buf, 1, nbytes, out);
+
+      DEBUG (c << " = fwrite (" << nbytes << ")");
+      if (errno)
+	DEBUG ("errno = " << errno);
+      if (ferror(out))
+	DEBUG ("ferror(out) = " << ferror (out));
+
     } while (c <= 0 && ferror(out) && errno == EINTR);
 
     if (c <= 0 && ferror(out))
@@ -1106,21 +1124,20 @@ NprVoidError Err_read_expect(int fd, void* buf, size_t nbytes)
 
 NprVoidError Err_write(int fd, const void* buf, size_t nbytes)
 {
-    int c = 0;
+    int c;
 
-    do {
+    while (nbytes > 0) {
+	do {
+	    c = write(fd, buf, nbytes);
+	} while (c < 0 && errno == EINTR);
+	
+	if (c < 0)
+	    return WriteFailure;
+	
 	nbytes -= c;
-
-	if (nbytes <= 0)
-	    break;
-
-	c = write(fd, buf, nbytes);
-     } while (c < 0 && errno == EINTR);
-
-    if (c < 0)
-	return WriteFailure;
-    else
-	return NoError;
+	buf = ((const char*)buf) + c;
+    }
+    return NoError;
 }
 
 NprIntError Err_open(const char* a, int flags, mode_t mode)
