@@ -16,11 +16,11 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  *
- * $Id: prcs.cc 1.23.1.1.1.14.1.18.1.8.1.16.1.1.1.7.1.32 Wed, 14 Oct 1998 20:50:34 -0700 jmacd $
+ * $Id: prcs.cc 1.23.1.1.1.14.1.18.1.8.1.16.1.1.1.7.1.35 Sun, 31 Oct 1999 16:52:32 -0800 jmacd $
  */
 
 /* $Format: "static const char prcs_version_id[] = \"$ProjectVersion$ $ProjectAuthor$ $ProjectDate$\";"$ */
-static const char prcs_version_id[] = "1.2-release.80 jmacd Mon, 02 Nov 1998 23:28:03 -0800";
+static const char prcs_version_id[] = "1.2-release.94 jmacd Tue, 09 Nov 1999 14:40:19 -0800";
 
 #include "prcs.h"
 #include "lock.h"
@@ -44,7 +44,7 @@ extern "C" {
 }
 
 /* $Format: "const char prcs_version_string[] = \"$ReleaseVersion$\";"$ */
-const char prcs_version_string[] = "1.2.11";
+const char prcs_version_string[] = "1.2.15";
 
 /* The following classes are only used inside this file, and oraganize
  * several arrays of information used to select the command and
@@ -241,7 +241,7 @@ static PrcsCommand commands[] = {
 
     {"execute", "", "", "@", NoFlags,
      execute_command, execute_help_string,
-     OneRevisionArg, InsureProjectName, EXECUTE_STR, ReallyExecuteArgs, -1 },
+     OneRevisionArg, InsureProjectName, "P" EXECUTE_STR, ReallyExecuteArgs, -1 },
 
     /* commands not accepting -r */
     {"populate", NULL, NULL, NULL, NoFlags,
@@ -1129,7 +1129,11 @@ static void handle_signals()
 
     act.sa_handler = clean_up_handler;
     act.sa_mask = signal_mask;
+#ifdef SA_RESTART
+    act.sa_flags = SA_RESTART;
+#else
     act.sa_flags = 0;
+#endif
 
     for(i = 0; friendly_signals[i]; i += 1)
 	sigaction(friendly_signals[i], &act, NULL);
