@@ -16,7 +16,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  *
- * $Id: prcserror.cc 1.8.1.11.1.3.1.7.1.9 Tue, 20 May 1997 22:48:31 -0700 jmacd $
+ * $Id: prcserror.cc 1.8.1.11.1.3.1.7.1.11 Tue, 29 Sep 1998 13:26:59 -0700 jmacd $
  */
 
 
@@ -43,7 +43,7 @@ static int argc_save;
 const char* re_query_message = NULL;
 int re_query_len;
 
-#ifndef PRCS_DEVEL
+#if !defined(PRCS_DEVEL) || !defined(__GNUG__)
 ErrorToken global_error_token;
 int return_if_fail_if_ne_val;
 #endif
@@ -103,6 +103,10 @@ int PrettyStreambuf::overflow(int c)
 
 int PrettyStreambuf::xsputn(const char* s0, int n0)
 {
+#ifndef __GNUG__
+#  define xsputn sputn
+#endif
+
     if (dont_print && *dont_print)
 	return n0;
 
@@ -180,12 +184,20 @@ int PrettyStreambuf::xsputn(const char* s0, int n0)
     }
 
     return n;
+
+#ifndef __GNUG__
+#  undef xsputn
+#endif
 }
 
 int PrettyStreambuf::sync()
 {
     xsputn(NULL, 0);
+#ifdef __GNUG__
     return forward->sync();
+#else
+    return forward->pubsync();
+#endif
 }
 
 static int tty_width(int fileno)
@@ -203,8 +215,13 @@ static int tty_width(int fileno)
 
 void re_query()
 {
+#ifdef __GNUG__
     stdout_stream.xsputn(re_query_message, re_query_len);
     stdout_stream.sync();
+#else
+    stdout_stream.sputn(re_query_message, re_query_len);
+    stdout_stream.pubsync();
+#endif
 }
 
 void continue_handler(SIGNAL_ARG_TYPE)
@@ -302,7 +319,11 @@ ostream& __omanip_setcol(ostream& o, int col)
 {
     PrettyStreambuf& ps = ((PrettyOstream&)o).ostreambuf();
 
+#ifdef __GNUG__
     ps.xsputn(NULL, 0);
+#else
+    ps.sputn(NULL, 0);
+#endif
     ps.set_column(col);
 
     return o;
@@ -379,7 +400,11 @@ ostream& prcsendl(ostream& s)
 {
     PrettyStreambuf &ps = ((PrettyOstream&)s).ostreambuf();
 
+#ifdef __GNUG__
     ps.xsputn("\n", 1);
+#else
+    ps.sputn("\n", 1);
+#endif
 
     ps.reset_column();
 
@@ -390,7 +415,11 @@ ostream& dotendl(ostream& s)
 {
     PrettyStreambuf &ps = ((PrettyOstream&)s).ostreambuf();
 
+#ifdef __GNUG__
     ps.xsputn(".\n", 2);
+#else
+    ps.sputn(".\n", 2);
+#endif
 
     ps.reset_column();
 
@@ -414,19 +443,25 @@ const char* PrettyStreambuf::fill_prefix() const  { return prefix.cast(); }
 PrettyStreambuf::PrettyStreambuf(streambuf *forward0, int* dont_print0)
     :streambuf(), forward(forward0), col(0),
      width(80), breakon(true), prettyon(true),
-     new_line(true), dont_print(dont_print0) { }
+     new_line(true), dont_print(dont_print0) {
+}
 
 /* QueryOstream */
 QueryOstream::QueryOstream(strstreambuf* base_stream0,
 			   PrettyStreambuf* query_stream0,
 			   stdiobuf* stdout_stream0,
 			   stdiobuf* stderr_stream0)
-    :PrettyOstream(query_stream0, NoError),
+    :
+#ifndef __GNUG__
+     ios(query_stream0),
+#endif
+     PrettyOstream(query_stream0, NoError),
      base_stream(base_stream0),
      query_stream(query_stream0),
      stdout_stream(stdout_stream0),
      stderr_stream(stderr_stream0),
-     val(0), string_val((const char*) 0), default_option(0),
+     val(0), string_val((const char*) 0),
+     default_option(0), force_option(0),
      force_message(NULL), report_message(NULL),
      option_count(0), bang_flag(NULL) { }
 
@@ -455,6 +490,13 @@ ostream& QueryOstream::force_manip(const char* message)
     return *this;
 }
 
+ostream& QueryOstream::force_manip(const char* message, char different)
+{
+    force_message = message;
+    force_option = different;
+    return *this;
+}
+
 ostream& QueryOstream::definput_manip(const char* input)
 {
     default_input = input;
@@ -469,6 +511,11 @@ ostream& QueryOstream::bang(BangFlag* flag)
 
 ostream& QueryOstream::string_query_manip(const char* message)
 {
+#ifndef __GNUG__
+#  define xsputn       sputn
+#  define sync         pubsync
+#  define seekoff(p,w) pubseekoff((p),(w), ios::out)
+#endif
     if(option_force_resolution && option_be_silent) {
 	/* silence */
     } else if(option_force_resolution) {
@@ -520,10 +567,16 @@ ostream& QueryOstream::string_query_manip(const char* message)
     base_stream->freeze(0);
     base_stream->seekoff(0, ios::beg);
     option_count = 0;
+    force_option = 0;
     bang_flag = NULL;
     help_string = NULL;
 
     return *this;
+#ifndef __GNUG__
+#  undef xsputn
+#  undef sync
+#  undef seekoff
+#endif
 }
 
 ostream& QueryOstream::help_manip(const char* message)
@@ -534,8 +587,23 @@ ostream& QueryOstream::help_manip(const char* message)
 
 ostream& QueryOstream::query_manip(const char* message)
 {
+#ifndef __GNUG__
+#  define xsputn  sputn
+#  define sync    pubsync
+#  define seekoff(p,w) pubseekoff((p),(w), ios::out)
+#endif
+    if(force_option != 0 && option_force_resolution) {
+        for (int i = 0; i < option_count; i += 1) {
+	    if (force_option == options[i].let) {
+	        default_option = i;
+		break;
+	    }
+	}
+    }
+
     if(option_force_resolution && option_be_silent) {
 	/* silence */
+	val = options[default_option].val;
     } else if(option_report_actions) {
 	*this << report_message << dotendl;
 	query_stream->sync();
@@ -646,11 +714,17 @@ ostream& QueryOstream::query_manip(const char* message)
     query_stream->reset_column();
     base_stream->freeze(0);
     base_stream->seekoff(0, ios::beg);
+    force_option = 0;
     option_count = 0;
     bang_flag = NULL;
     help_string = NULL;
 
     return *this;
+#ifndef __GNUG__
+#  undef xsputn
+#  undef sync
+#  undef seekoff
+#endif
 }
 
 ostream& __omanip_query(ostream& s, const char* message) {
@@ -678,6 +752,11 @@ ostream& __omanip_force(ostream& s, const char* message) {
 omanip<const char*> force(const char* message) {
     return omanip<const char*>(__omanip_force, message); }
 
+ostream& __omanip_force(ostream& s, CharAndStr cas) {
+    return ((QueryOstream&)s).force_manip(cas.str, cas.c); }
+omanip<CharAndStr> force(const char* message, char different) {
+    return omanip<CharAndStr>(__omanip_force, CharAndStr (message, different)); }
+
 ostream& __omanip_report(ostream& s, const char* message) {
     return ((QueryOstream&)s).report_manip(message); }
 omanip<const char*> report(const char* message) {
@@ -732,6 +811,20 @@ omanip<FileTuple> diff_tuple(FileEntry* from,
 omanip<int> setcol(int col)
     { return omanip<int>(__omanip_setcol, col); }
 
+#if defined(__MWERKS__) && defined(EXPLICIT_TEMPLATES)
+/* Some methods are not defined, propably because
+ * they haven't been used yet. However, to instantiate them
+ * there must be something.
+ */
+
+template<class Type> PrError<Type>::operator!()
+{
+  ASSERT(false, "Undefined method PrError::operator!() called");
+  return true;
+}
+
+#endif
+
 #if EXPLICIT_TEMPLATES
 #include "prcserror.tl"
 #endif
