@@ -16,7 +16,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  *
- * $Id: projdesc.cc 1.9.1.1.1.4.1.17.1.5.1.17.3.9.1.31 Wed, 14 Oct 1998 20:50:34 -0700 jmacd $
+ * $Id: projdesc.cc 1.9.1.1.1.4.1.17.1.5.1.17.3.9.1.32 Sat, 30 Oct 1999 21:26:02 -0700 jmacd $
  */
 
 extern "C" {
@@ -963,7 +963,7 @@ PrVoidError ProjectDescriptor::verify_project_file()
 
     Dstring project_descriptor;
 
-    project_descriptor.sprintf("%s.prj", project_name(), project_name());
+    project_descriptor.sprintf("%s.prj", project_name());
 
     /* Using the project_file_path and project_file_aux will
      * be wrong later */
