@@ -16,7 +16,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  *
- * $Id: rebuild.cc 1.3.1.1.1.8.1.21.1.4.1.4.1.10 Thu, 17 Jul 1997 14:10:28 -0700 jmacd $
+ * $Id: rebuild.cc 1.3.1.1.1.8.1.21.1.4.1.4.1.12 Tue, 06 Oct 1998 13:31:13 -0700 jmacd $
  */
 
 extern "C" {
@@ -126,7 +126,7 @@ static PrVoidError compute_cksum(const char* versionfile, RcsVersionData* ver)
     Return_if_fail(cofile << VC_checkout_stream(ver->rcs_version(), versionfile));
 
     If_fail(read_buf.map_file(fileno(cofile)))
-	throw prcserror << "Read failed from RCS co pipe" << dotendl;
+	pthrow prcserror << "Read failed from RCS co pipe" << dotendl;
 
     ver->length(read_buf.length());
 
@@ -147,7 +147,7 @@ PrVoidError create_empty_data(const char* project, const char* filename0)
     write_data_file_header(new_data, project);
 
     if(new_data.bad()) {
-	throw prcserror << "Failed creating new repository data file "
+	pthrow prcserror << "Failed creating new repository data file "
 			 << squote(filename0) << perror;
     }
 
@@ -310,7 +310,7 @@ static PrVoidError reference_versions(const char* project_file_name,
 
 	if((lookup = file_table->lookup(fe->descriptor_name())) == NULL) {
 	    /*delete project;*/
-	    throw prcserror << "Version file "
+	    pthrow prcserror << "Version file "
 			    << squote(fe->descriptor_name())
 			    << " referenced by project version "
                             << project_data
@@ -323,7 +323,7 @@ static PrVoidError reference_versions(const char* project_file_name,
 
 	if(!version_data) {
 	    /*delete project;*/
-	    throw prcserror << "Version " << fe->descriptor_version_number()
+	    pthrow prcserror << "Version " << fe->descriptor_version_number()
 			    << " in repository file "
 			    << squote(fe->descriptor_name())
 			    << " referenced by project version "
@@ -398,7 +398,7 @@ static PrRcsDeltaPtrError rebuild_repository_file(RepEntry* rep_entry,
 
 	if(!option_report_actions) {
 	    If_fail(Err_unlink(name))
-		throw prcserror << "Unlink failed on "
+		pthrow prcserror << "Unlink failed on "
 				 << squote(name) << perror;
 	}
 
@@ -487,7 +487,7 @@ static PrVoidError rebuild_repository(RepEntry *rep_ptr,
 
     /* Unlink here in case we're mmaping the file that's about to get truncated. */
     If_fail(Err_unlink(rep_ptr->Rep_name_in_entry(prcs_data_file_name))) {
-	throw prcserror << "Unlink failed on old repository data file "
+	pthrow prcserror << "Unlink failed on old repository data file "
 			<< squote(rep_ptr->Rep_name_in_entry(prcs_data_file_name))
 			<< perror;
     }
@@ -519,7 +519,7 @@ static PrVoidError rebuild_repository(RepEntry *rep_ptr,
     new_data.close();
 
     if(new_data.bad()) {
-	throw prcserror << "Write failed to reconstructed project data file "
+	pthrow prcserror << "Write failed to reconstructed project data file "
 			<< squote(rep_ptr->Rep_name_in_entry(prcs_data_file_name))
 			<< perror;
     }
@@ -599,11 +599,11 @@ PrPrcsExitStatusError delete_command()
 #if 0
     @@@@
     if(project_data->prcs_minor_int() == 0)
-	throw prcserror << "You may not delete minor version 0" << dotendl;
+	pthrow prcserror << "You may not delete minor version 0" << dotendl;
 #endif
 
     if(project_data->deleted())
-	throw prcserror << "That version is already deleted" << dotendl;
+	pthrow prcserror << "That version is already deleted" << dotendl;
 
     prcsquery << "Delete version "
 	      << project_data
@@ -633,7 +633,7 @@ PrPrcsExitStatusError delete_command()
 /* Called when something goes wrong reading a data file */
 PrVoidError RebuildFile::bad_data_file()
 {
-    throw prcserror << "Invalid repository data file "
+    pthrow prcserror << "Invalid repository data file "
 		    << squote(source_name())
 		    << ".  Please run " << squote("prcs admin rebuild")
 		    << " to rebuild the data file"
@@ -651,7 +651,7 @@ PrVoidError RebuildFile::read_header()
 
     for (int i = 0; old_data_file_headers[i]; i += 1) {
 	if (strncmp (s, old_data_file_headers[i], data_file_length) == 0) {
-	    throw prcserror << "The repository data file is outdated, you must run "
+	    pthrow prcserror << "The repository data file is outdated, you must run "
 			    << squote ("prcs admin rebuild")
 			    << " to rebuild the data file" << dotendl;
 	}
@@ -798,7 +798,7 @@ PrVoidError RebuildFile::init_from_file(const char* filename0, bool write)
     seg = new MemorySegment(false, write);
 
     If_fail(seg->map_file(filename0))
-	throw prcserror << "Failed opening project data file "
+	pthrow prcserror << "Failed opening project data file "
 			<< squote(filename0) << perror;
 
     last = seg->segment() + seg->length();
@@ -897,8 +897,13 @@ bool RebuildFile::done() { return offset == seg->length(); }
 void RebuildFile::init_stream()
 {
     if(!buf) {
+#ifdef __GNUG__
 	buf = new filebuf(seg->fd());
 	buf->seekoff(0,ios::end);
+#else
+        buf = new filebuf(fdopen(dup(seg->fd()), "a+"));
+        buf->pubseekoff(0,ios::end, ios::out);
+#endif
 	os = new ostream(buf);
     }
 }
@@ -945,7 +950,7 @@ PrVoidError RebuildFile::update_project_data()
     return NoError;
 
 error:
-    throw prcserror << "Failed updating repository data file"
+    pthrow prcserror << "Failed updating repository data file"
 		    << squote(source_name()) << perror;
 }
 
