@@ -16,7 +16,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  *
- * $Id: vc.cc 1.13.1.1.1.11.1.12.1.11.1.6.1.11 Thu, 09 Oct 1997 20:11:02 -0700 jmacd $
+ * $Id: vc.cc 1.13.1.1.1.11.1.12.1.11.1.6.1.17 Tue, 13 Oct 1998 13:28:35 -0700 jmacd $
  */
 
 extern "C" {
@@ -95,16 +95,14 @@ struct CheckinData {
 		const char* ver0,
 		const char* log0,
 		void* data0,
-		CheckinHook notify_func0,
-		bool keep0)
+		CheckinHook notify_func0)
 	:file(file0), ver(ver0), log(log0), data(data0),
-	 notify_func(notify_func0), keep(keep0) { }
+	 notify_func(notify_func0) { }
     const char* file;
     const char* ver;
     const char* log;
     void* data;
     CheckinHook notify_func;
-    bool keep;
 };
 
 struct CheckinData2 {
@@ -123,11 +121,10 @@ PrVoidError VC_checkin(const char* newfile,
 		       const char* versionfile,
 		       const char* log,
 		       void* data,
-		       CheckinHook notify_func,
-		       bool keep)
+		       CheckinHook notify_func)
 {
     CheckinData* c_data = new CheckinData(newfile, versionfile,
-					   log, data, notify_func, keep);
+					   log, data, notify_func);
 
     /*
      * if the file being checked in has a parent version, then
@@ -206,14 +203,13 @@ PrVoidError VC_checkin_stage2(MemorySegment*, MemorySegment*, int exit_val, void
     const char* newfile = c_data->file;
     const char* log = c_data->log;
     const char* versionfile = c_data->ver;
-    bool keep = c_data->keep;
     void* data = c_data->data;
     CheckinHook func = c_data->notify_func;
 
     delete c_data;
 
     if (exit_val != 0)
-	throw prcserror << "RCS failed on file " << versionfile;
+      pthrow prcserror << "RCS failed on file " << versionfile << dotendl;;
 
     if (!args && !accumulate && !newfile)
 	return NoError;
@@ -229,6 +225,14 @@ PrVoidError VC_checkin_stage2(MemorySegment*, MemorySegment*, int exit_val, void
 	int files_per_proc = 4 > ratio ? 4 : ratio;
 	int max_arg_size   = sysconf(_SC_ARG_MAX) - (4 * MAXPATHLEN);
 
+#ifdef __BEOS__
+        /* ci sometimes freezes when given more than one file,
+         * and is remarkably slow when given more then 32 files in
+         * any case. *sigh*
+         */
+        files_per_proc = 1;
+#endif
+
 	DEBUG ("using " << files_per_proc << " files per child");
 
 	VoidPtrList* acc_end;
@@ -262,8 +266,8 @@ PrVoidError VC_checkin_stage2(MemorySegment*, MemorySegment*, int exit_val, void
 	    ci_args->append("-T");
 	    ci_args->append("-f");
 
-	    if (keep)
-		ci_args->append("-u");
+	    /*if (keep)
+		ci_args->append("-u");*/
 
 	    for (; j < file_count &&
 		     arg_list_size < max_arg_size &&
@@ -315,7 +319,7 @@ PrVoidError VC_checkin_stage3(MemorySegment*, MemorySegment* err_seg, int exit_v
 
     if (exit_val != 0) {
 	cerr.write(err_seg->segment(), err_seg->length());
-	throw prcserror << "RCS ci failed on batch command" << dotendl;
+	pthrow prcserror << "RCS ci failed on batch command" << dotendl;
     }
 
     VC_init_seg_get(err_seg);
@@ -327,7 +331,7 @@ PrVoidError VC_checkin_stage3(MemorySegment*, MemorySegment* err_seg, int exit_v
 	if(vclex != NewRevision &&
 	   vclex != PrevRevision &&
 	   vclex != InitialRevision)
-	    throw prcserror << "Error scanning RCS ci output" << dotendl;
+	    pthrow prcserror << "Error scanning RCS ci output" << dotendl;
 
 	if (l->head() != NULL)
 	    (* func) (l->head(), rcs_text);
@@ -422,7 +426,7 @@ PrVoidError VC_register(const char* file)
 	n_success = false;
 
 	if (tmp)
-	    throw prcserror << "RCS -i failed on batch init" << dotendl;
+	    pthrow prcserror << "RCS -i failed on batch init" << dotendl;
     }
 
     return NoError;
@@ -480,7 +484,7 @@ PrCFilePtrError VC_checkout_stream(const char* version,
     argl->append(revisionfile);
 
     If_fail(co_command.open(true, true))
-        throw prcserror << "Failed checking out version " << version
+        pthrow prcserror << "Failed checking out version " << version
 			 << " from file " << squote(revisionfile) << dotendl;
 
     return co_command.standard_out();
@@ -507,13 +511,13 @@ PrVoidError VC_close_checkout_stream(FILE* UNUSED(f), const char* version, const
 {
     if(!VC_expect_token(co_command.standard_err(), RlogVersion, NULL) ||
        strcmp(rcs_text, version) != 0)
-        throw prcserror << "Consistency check failed checking out version "
+        pthrow prcserror << "Consistency check failed checking out version "
 			 << version << " from file " << squote(file) << dotendl;
 
     ASSERT(f == co_command.standard_out(), "no way, man!");
 
     Return_if_fail_if_ne(co_command.close(), 0)
-	throw prcserror << "co exited with non-zero status" << dotendl;
+	pthrow prcserror << "co exited with non-zero status" << dotendl;
 
     return NoError;
 }
@@ -538,14 +542,14 @@ PrVoidError VC_checkout_file(const char* newfile,
     Return_if_fail(infile << VC_checkout_stream(version, revisionfile));
 
     If_fail(outfile << Err_fopen(newfile, "w"))
-        throw prcserror << "Can't open file " << squote(newfile)
+        pthrow prcserror << "Can't open file " << squote(newfile)
 		         << " for writing" << perror;
 
     Return_if_fail(write_file(infile, outfile));
     Return_if_fail(VC_close_checkout_stream(infile, version, revisionfile));
 
     If_fail(Err_fclose(outfile))
-	throw prcserror << "Write failed on file " << squote(newfile) << perror;
+	pthrow prcserror << "Write failed on file " << squote(newfile) << perror;
 
     return NoError;
 }
@@ -578,7 +582,7 @@ VC_get_project_version_data(const char* versionfile)
     if(VC_get_token(rlog_command.standard_out()) == RlogTotalRevisions)
 	rev_count = atoi(rcs_text);
     else
-	throw prcserror << "Unrecognized output from RCS rlog command on RCS file "
+	pthrow prcserror << "Unrecognized output from RCS rlog command on RCS file "
 			<< squote(versionfile) << dotendl;
 
     ProjectVersionDataPtrArray* pvda = new ProjectVersionDataPtrArray (rev_count);
@@ -676,7 +680,7 @@ VC_get_project_version_data(const char* versionfile)
 		    int pi = atoi (pis);
 
 		    if (!pis[0] || pi < 0 || pi >= (rev_count - 1 - i))
-			throw prcserror << "Invalid parent version index " << squote (rcs_text)
+			pthrow prcserror << "Invalid parent version index " << squote (rcs_text)
 					<< " in " << squote (versionfile)
 					<< " RCS version 1." << (rev_count - i) << dotendl;
 
@@ -686,7 +690,7 @@ VC_get_project_version_data(const char* versionfile)
 			pi = atoi (pis);
 
 			if (!pis[0] || pi < 0 || pi >= (rev_count - 1 - i))
-			    throw prcserror << "Invalid parent version index " << squote (rcs_text)
+			    pthrow prcserror << "Invalid parent version index " << squote (rcs_text)
 					    << " in " << squote (versionfile)
 					    << " RCS version 1." << (rev_count - i) << dotendl;
 
@@ -710,13 +714,13 @@ VC_get_project_version_data(const char* versionfile)
 	}
 
 	if (!pvd->OK())
-	    throw prcserror << "Incomplete version log information in RCS file "
+	    pthrow prcserror << "Incomplete version log information in RCS file "
 			    << squote(versionfile)
 			    << " version 1." << (rev_count - i) << dotendl;
     }
 
     Return_if_fail_if_ne(rlog_command.close(), 0)
-	throw prcserror << "RCS rlog command returned non-zero status on RCS file "
+	pthrow prcserror << "RCS rlog command returned non-zero status on RCS file "
 			<< squote(versionfile) << dotendl;
 
     Return_if_fail(fix_version_data(pvda, old_fmt_parents));
@@ -736,7 +740,7 @@ error:
     delete old_fmt_parents;
     delete pvda;
 
-    throw prcserror << "Error scanning RCS rlog output on RCS file "
+    pthrow prcserror << "Error scanning RCS rlog output on RCS file "
 		    << squote(versionfile) << dotendl;
 
 }
@@ -796,7 +800,7 @@ VC_get_version_data(const char* versionfile)
     if(VC_get_token(rlog_command.standard_out()) == RlogTotalRevisions)
 	rev_count = atoi(rcs_text);
     else
-	throw prcserror << "Unrecognized output from RCS rlog command on RCS file "
+	pthrow prcserror << "Unrecognized output from RCS rlog command on RCS file "
 			<< squote(versionfile) << dotendl;
 
     RcsDelta* pvda = new RcsDelta(NULL);
@@ -849,18 +853,18 @@ VC_get_version_data(const char* versionfile)
 	}
 
 	if(!pvd->OK())
-	    throw prcserror << "Incomplete version log information in RCS file "
+	    pthrow prcserror << "Incomplete version log information in RCS file "
 			    << squote(versionfile) << dotendl;
     }
 
     Return_if_fail_if_ne(rlog_command.close(), 0)
-	throw prcserror << "RCS rlog command returned non-zero status on RCS file "
+	pthrow prcserror << "RCS rlog command returned non-zero status on RCS file "
 			<< squote(versionfile) << dotendl;
 
     return pvda;
 
 error:
-    throw prcserror << "Error scanning RCS rlog output on RCS file "
+    pthrow prcserror << "Error scanning RCS rlog output on RCS file "
 		    << squote(versionfile) << dotendl;
 
 }
@@ -908,7 +912,7 @@ PrVoidError VC_set_log(const char* new_log_text,
     Return_if_fail(rcs_command.open(true, true));
 
     Return_if_fail_if_ne(rcs_command.close(), 0) {
-	throw prcserror << "RCS exited abnormally while updating log" << dotendl;
+	pthrow prcserror << "RCS exited abnormally while updating log" << dotendl;
     }
 
     return NoError;
@@ -1064,6 +1068,7 @@ bool RcsDelta::DeltaIterator::finished() const { return _finished; }
 RcsVersionData::RcsVersionData()
     :_date(0), _author(NULL),
      _rcs_version(NULL), _gc_mark(NotReferenced) { }
+RcsVersionData::~RcsVersionData() { }
 
 time_t RcsVersionData::date() const { return _date; }
 int RcsVersionData::length() const { return _length; }
@@ -1087,6 +1092,7 @@ ProjectVersionData::ProjectVersionData(int index)
      _prcs_major(NULL), _prcs_minor(NULL),
      _prcs_minor_int(-1), _index(index),
      _deleted(false) { }
+ProjectVersionData::~ProjectVersionData() { }
 
 void ProjectVersionData::clear_flags() { _flag1 = false; _flag2 = false; }
 bool ProjectVersionData::flag1(bool n) { bool o = _flag1; _flag1 = n; return o; }
